@@ -6,6 +6,7 @@ import openapi_client
 import klaviyo_api.custom_retry as custom_retry
 from dataclasses import dataclass
 from typing import Callable, ClassVar
+from openapi_client.api import campaigns_api
 from openapi_client.api import catalogs_api
 from openapi_client.api import client_api
 from openapi_client.api import data_privacy_api
@@ -27,7 +28,7 @@ class KlaviyoAPI:
     max_retries: int = 3
     test_host: str = ''
 
-    _REVISION = "2023-01-24"
+    _REVISION = "2023-02-22"
 
     _STATUS_CODE_TOO_MANY_REQUESTS = 429
     _STATUS_CODE_SERVICE_UNAVAILABLE = 503
@@ -70,6 +71,29 @@ class KlaviyoAPI:
         )
 
         
+        ## Adding Campaigns to Client
+        self.Campaigns=campaigns_api.CampaignsApi(self.api_client)
+        
+        ## Applying tenacity retry decorator to each endpoint in Campaigns
+        self.Campaigns.create_campaign=self._page_cursor_update(self.retry_logic(self.Campaigns.create_campaign))
+        self.Campaigns.create_campaign_clone=self._page_cursor_update(self.retry_logic(self.Campaigns.create_campaign_clone))
+        self.Campaigns.create_campaign_message_assign_template=self._page_cursor_update(self.retry_logic(self.Campaigns.create_campaign_message_assign_template))
+        self.Campaigns.create_campaign_recipient_estimation_job=self._page_cursor_update(self.retry_logic(self.Campaigns.create_campaign_recipient_estimation_job))
+        self.Campaigns.create_campaign_send_job=self._page_cursor_update(self.retry_logic(self.Campaigns.create_campaign_send_job))
+        self.Campaigns.delete_campaign=self._page_cursor_update(self.retry_logic(self.Campaigns.delete_campaign))
+        self.Campaigns.get_campaign=self._page_cursor_update(self.retry_logic(self.Campaigns.get_campaign))
+        self.Campaigns.get_campaign_message=self._page_cursor_update(self.retry_logic(self.Campaigns.get_campaign_message))
+        self.Campaigns.get_campaign_recipient_estimation=self._page_cursor_update(self.retry_logic(self.Campaigns.get_campaign_recipient_estimation))
+        self.Campaigns.get_campaign_recipient_estimation_job=self._page_cursor_update(self.retry_logic(self.Campaigns.get_campaign_recipient_estimation_job))
+        self.Campaigns.get_campaign_relationships=self._page_cursor_update(self.retry_logic(self.Campaigns.get_campaign_relationships))
+        self.Campaigns.get_campaign_send_job=self._page_cursor_update(self.retry_logic(self.Campaigns.get_campaign_send_job))
+        self.Campaigns.get_campaign_tags=self._page_cursor_update(self.retry_logic(self.Campaigns.get_campaign_tags))
+        self.Campaigns.get_campaigns=self._page_cursor_update(self.retry_logic(self.Campaigns.get_campaigns))
+        self.Campaigns.update_campaign=self._page_cursor_update(self.retry_logic(self.Campaigns.update_campaign))
+        self.Campaigns.update_campaign_message=self._page_cursor_update(self.retry_logic(self.Campaigns.update_campaign_message))
+        self.Campaigns.update_campaign_send_job=self._page_cursor_update(self.retry_logic(self.Campaigns.update_campaign_send_job))
+        
+        
         ## Adding Catalogs to Client
         self.Catalogs=catalogs_api.CatalogsApi(self.api_client)
         
