@@ -25,6 +25,9 @@ from openapi_client.model.campaign_message_partial_update_query_as_sub_resource_
 from openapi_client.model.campaign_partial_update_query import CampaignPartialUpdateQuery
 from openapi_client.model.campaign_partial_update_query_as_sub_resource import CampaignPartialUpdateQueryAsSubResource
 from openapi_client.model.campaign_partial_update_query_as_sub_resource_attributes import CampaignPartialUpdateQueryAsSubResourceAttributes
+from openapi_client.model.campaign_recipient_estimation_job_create_query import CampaignRecipientEstimationJobCreateQuery
+from openapi_client.model.campaign_recipient_estimation_job_create_query_as_sub_resource import CampaignRecipientEstimationJobCreateQueryAsSubResource
+from openapi_client.model.campaign_recipient_estimation_job_create_query_as_sub_resource_attributes import CampaignRecipientEstimationJobCreateQueryAsSubResourceAttributes
 from openapi_client.model.campaign_send_job_create_query import CampaignSendJobCreateQuery
 from openapi_client.model.campaign_send_job_create_query_as_sub_resource import CampaignSendJobCreateQueryAsSubResource
 from openapi_client.model.campaign_send_job_create_query_as_sub_resource_attributes import CampaignSendJobCreateQueryAsSubResourceAttributes
@@ -101,9 +104,9 @@ from openapi_client.model.event_create_query_as_sub_resource_attributes import E
 from openapi_client.model.flow_update_query import FlowUpdateQuery
 from openapi_client.model.flow_update_query_as_sub_resource import FlowUpdateQueryAsSubResource
 from openapi_client.model.flow_update_query_as_sub_resource_attributes import FlowUpdateQueryAsSubResourceAttributes
-from openapi_client.model.get_catalog_items4_xx_response import GetCatalogItems4XXResponse
-from openapi_client.model.get_catalog_items4_xx_response_errors_inner import GetCatalogItems4XXResponseErrorsInner
-from openapi_client.model.get_catalog_items4_xx_response_errors_inner_source import GetCatalogItems4XXResponseErrorsInnerSource
+from openapi_client.model.get_campaigns4_xx_response import GetCampaigns4XXResponse
+from openapi_client.model.get_campaigns4_xx_response_errors_inner import GetCampaigns4XXResponseErrorsInner
+from openapi_client.model.get_campaigns4_xx_response_errors_inner_source import GetCampaigns4XXResponseErrorsInnerSource
 from openapi_client.model.included_categories import IncludedCategories
 from openapi_client.model.included_categories_attributes import IncludedCategoriesAttributes
 from openapi_client.model.included_flow_action import IncludedFlowAction
@@ -124,6 +127,8 @@ from openapi_client.model.included_metrics_attributes import IncludedMetricsAttr
 from openapi_client.model.included_profiles import IncludedProfiles
 from openapi_client.model.included_profiles_attributes import IncludedProfilesAttributes
 from openapi_client.model.included_segments import IncludedSegments
+from openapi_client.model.included_segments_attributes import IncludedSegmentsAttributes
+from openapi_client.model.included_tags import IncludedTags
 from openapi_client.model.included_variants import IncludedVariants
 from openapi_client.model.included_variants_attributes import IncludedVariantsAttributes
 from openapi_client.model.included_variants_links import IncludedVariantsLinks
@@ -152,19 +157,23 @@ from openapi_client.model.profile_create_query_as_sub_resource import ProfileCre
 from openapi_client.model.profile_create_query_as_sub_resource_attributes import ProfileCreateQueryAsSubResourceAttributes
 from openapi_client.model.profile_location import ProfileLocation
 from openapi_client.model.profile_location_latitude import ProfileLocationLatitude
+from openapi_client.model.profile_location_longitude import ProfileLocationLongitude
 from openapi_client.model.profile_partial_update_query import ProfilePartialUpdateQuery
 from openapi_client.model.profile_partial_update_query_as_sub_resource import ProfilePartialUpdateQueryAsSubResource
 from openapi_client.model.sms_message_content import SMSMessageContent
 from openapi_client.model.sms_render_options import SMSRenderOptions
 from openapi_client.model.sms_tracking_options import SMSTrackingOptions
+from openapi_client.model.sto_schedule_options import STOScheduleOptions
 from openapi_client.model.segment_partial_update_query import SegmentPartialUpdateQuery
 from openapi_client.model.segment_partial_update_query_as_sub_resource import SegmentPartialUpdateQueryAsSubResource
+from openapi_client.model.segment_partial_update_query_as_sub_resource_attributes import SegmentPartialUpdateQueryAsSubResourceAttributes
 from openapi_client.model.send_options import SendOptions
 from openapi_client.model.send_options_sub_object import SendOptionsSubObject
 from openapi_client.model.send_strategy_sub_object import SendStrategySubObject
 from openapi_client.model.send_time_sub_object import SendTimeSubObject
 from openapi_client.model.static_schedule_options import StaticScheduleOptions
 from openapi_client.model.subscription import Subscription
+from openapi_client.model.subscription_channels import SubscriptionChannels
 from openapi_client.model.subscription_create_job_create_query import SubscriptionCreateJobCreateQuery
 from openapi_client.model.subscription_create_job_create_query_as_sub_resource import SubscriptionCreateJobCreateQueryAsSubResource
 from openapi_client.model.subscription_create_job_create_query_as_sub_resource_attributes import SubscriptionCreateJobCreateQueryAsSubResourceAttributes
@@ -208,4 +217,3 @@ from openapi_client.model.unsuppression_create_job_create_query import Unsuppres
 from openapi_client.model.unsuppression_create_job_create_query_as_sub_resource import UnsuppressionCreateJobCreateQueryAsSubResource
 from openapi_client.model.unsuppression_create_job_create_query_as_sub_resource_attributes import UnsuppressionCreateJobCreateQueryAsSubResourceAttributes
 from openapi_client.model.utm_param_info import UtmParamInfo
-from openapi_client.model.v2_template_render_query_as_sub_resource import V2TemplateRenderQueryAsSubResource
